@@ -132,6 +132,10 @@ pub fn load_vector_instructions(map: &mut HashMap<String, Instruction>) {
         String::from("BOOLVECTOR.DUP"),
         Instruction::new(bool_vector_dup),
     );
+    map.insert(
+        String::from("BOOLVECTOR.COUNT"),
+        Instruction::new(bool_vector_count),
+    );
     map.insert(
         String::from("BOOLVECTOR.EQUAL"),
         Instruction::new(bool_vector_equal),
@@ -173,10 +177,6 @@ pub fn load_vector_instructions(map: &mut HashMap<String, Instruction>) {
         Instruction::new(bool_vector_zeros),
     );
 
-    map.insert(
-        String::from("INTVECTOR.BOOLINDEX"),
-        Instruction::new(int_vector_bool_index),
-    );
     map.insert(
         String::from("INTVECTOR.GET"),
         Instruction::new(int_vector_get),
@@ -441,6 +441,15 @@ fn bool_vector_equal(push_state: &mut PushState, _instruction_cache: &Instructio
     }
 }
 
+/// BOOLVECTOR.COUNT: Pushes the sum of all flipped bits to the INTEGER stack
+pub fn bool_vector_count(push_state: &mut PushState, _instruction_cache: &InstructionCache) {
+    if let Some(bv) = push_state.bool_vector_stack.pop() {
+        push_state
+            .int_stack
+            .push(bv.values.iter().filter(|&n| *n == true).count() as i32);
+    }
+}
+
 /// BOOLVECTOR.FLUSH: Empties the BOOLVECTOR stack.
 pub fn bool_vector_flush(push_state: &mut PushState, _instruction_cache: &InstructionCache) {
     push_state.bool_vector_stack.flush();
@@ -525,23 +534,6 @@ pub fn bool_vector_zeros(push_state: &mut PushState, _instruction_cache: &Instru
 
 /////////////////////////////////////// INTVECTOR //////////////////////////////////////////
 
-/// INTVECTOR.BOOLINDEX: Pushes an INTVECTOR item that contains the indices of all true values
-/// of the top BOOLVECTOR item. For example, this instruction pushes INT[0,2] if the top item
-/// on the BOOLVECTOR stack is BOOL[1,0,1]. The BOOLVECTOR item is popped.
-pub fn int_vector_bool_index(push_state: &mut PushState, _instruction_cache: &InstructionCache) {
-    if let Some(bvval) = push_state.bool_vector_stack.pop() {
-        let mut index_vector = vec![];
-        for (i, bval) in bvval.values.iter().enumerate() {
-            if *bval {
-                index_vector.push(i as i32);
-            }
-        }
-        push_state
-            .int_vector_stack
-            .push(IntVector::new(index_vector));
-    }
-}
-
 /// INTVECTOR.GET: Copies the element at index i of the top INTVECTOR item to the INTEGER stack
 /// where i taken from the INTEGER stack.
 pub fn int_vector_get(push_state: &mut PushState, _instruction_cache: &InstructionCache) {
@@ -777,7 +769,7 @@ pub fn int_vector_zeros(push_state: &mut PushState, _instruction_cache: &Instruc
 ////////////////////////////////////// FLOATVECTOR //////////////////////////////////////////
 
 /// FLOATVECTOR.GET: Copies the element at index i of the top FLOATVECTOR item to the FLOAT stack
-/// where i taken from the FLOAT stack.
+/// where i is taken from the FLOAT stack.
 pub fn float_vector_get(push_state: &mut PushState, _instruction_cache: &InstructionCache) {
     if let Some(index) = push_state.int_stack.pop() {
         if let Some(element) = push_state.float_vector_stack.get(0) {
@@ -789,8 +781,8 @@ pub fn float_vector_get(push_state: &mut PushState, _instruction_cache: &Instruc
     }
 }
 
-/// FLOATVECTOR.SET: Replaces the ith element of the top FLOATVECTOR item by the second item of the
-/// INTVECTOR stack. The top item of the INTEGER stack is the index i.
+/// FLOATVECTOR.SET: Replaces the ith element of the top FLOATVECTOR item by the top item of the
+/// FLOAT stack. The top item of the INTEGER stack is the index i.
 pub fn float_vector_set(push_state: &mut PushState, _instruction_cache: &InstructionCache) {
     if let Some(index) = push_state.int_stack.pop() {
         if let Some(new_element) = push_state.float_stack.pop() {
@@ -1092,6 +1084,16 @@ mod tests {
         );
     }
 
+    #[test]
+    fn bool_vector_count_pushes_number_of_true() {
+        let mut test_state = PushState::new();
+        test_state
+            .bool_vector_stack
+            .push(BoolVector::from_int_array(vec![1, 0, 0, 1, 1, 0, 1, 0]));
+        bool_vector_count(&mut test_state, &icache());
+        assert_eq!(test_state.int_stack.pop().unwrap(), 4);
+    }
+
     #[test]
     fn bool_vector_get_pushes_vector_element() {
         let test_vec1 = BoolVector::from_int_array(vec![1, 1, 1, 0, 1, 1, 1, 1]);
@@ -1406,19 +1408,6 @@ mod tests {
         assert_eq!(iv.to_string(), "[1,2,-3]");
     }
 
-    #[test]
-    fn int_vector_bool_index_pushes_indices_of_active_bits() {
-        let mut test_state = PushState::new();
-        test_state
-            .bool_vector_stack
-            .push(BoolVector::from_int_array(vec![1, 0, 0, 1, 0]));
-        int_vector_bool_index(&mut test_state, &icache());
-        assert_eq!(
-            test_state.int_vector_stack.pop().unwrap(),
-            IntVector::new(vec![0, 3])
-        );
-    }
-
     #[test]
     fn int_vector_get_pushes_vector_element() {
         let test_vec1 = IntVector::new(vec![1, 1, 1, 0, 1, 1, 1, 1]);
